@@ -11,7 +11,7 @@ use Date::Calc qw(Day_of_Week check_date);
 use List::MoreUtils qw(all any);
 use Params::Validate ':all';
 
-our $VERSION = '0.72_02';
+our $VERSION = '0.73_01';
 
 validation_options(
     on_fail => sub
@@ -68,7 +68,8 @@ sub _init_check
             regex => qr!^(?:[dmy]{1,4}[-./]){2}[dmy]{1,4}$!i,
         },
         prefer_future => {
-            type => BOOLEAN,
+            # SCALARREF due to boolean.pm's implementation
+            type => BOOLEAN | SCALARREF,
             optional => true,
         },
         time_zone => {
@@ -506,7 +507,7 @@ Specifies the format of numeric dates, defaults to 'C<d/m/y>'.
 
 =item * C<prefer_future>
 
-Turns ambigious weekdays/months to their futuristic relatives. Accepts a boolean,
+Turns ambiguous weekdays/months to their futuristic relatives. Accepts a boolean,
 defaults to false.
 
 =item * C<time_zone>
@@ -516,7 +517,7 @@ recognized by L<DateTime>. Defaults to 'floating'.
 
 =item * C<daytime>
 
-A hash consisting of specific hours given for peculiar daytimes. Daytimes may be
+A hash reference consisting of customized daytime hours, which may be
 selectively changed.
 
 =back
@@ -556,12 +557,12 @@ string given.
 
 =head2 error
 
-Returns the error message if the parsing didn't succeed.
+Returns the error message if the parsing did not succeed.
 
 =head2 trace
 
-Returns a trace of methods which we're called within the Base class and
-a summary how often certain units were modified.
+Returns a trace of methods which were called within the Base class and
+a summary how often certain units have been modified.
 
 =head1 GRAMMAR
 
